;; Generated package description from map.el  -*- no-byte-compile: t -*-
(define-package "map" "3.3.1.0.20240221.84915" "Map manipulation functions" '((emacs "26")) :commit "7f377407b4b7d6ac9994ed983d7516bc42139885" :url "https://elpa.gnu.org/packages/map.html" :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("extensions" "lisp"))
